.. highlight:: console


=====
Usage
=====

To see the available help run::

    $ geoip2_tools --help


Example::

    <help>


To see the help of a command::

    $ geoip2_tools <command> --help

For example::

    $ geoip2_tools ...


